import axios from 'axios';
import express from "express"
import * as dotenv from "dotenv";

dotenv.config({path: '../../.env'})
const key = process.env.OPEN_TRIP_MAPS_KEY

/**
 * make GET request to the OTM for radius search.
 * @param {string} lon Longitude of radius center point
 * @param {string} lat Latitude du point central du rayon
 * @param {string} radius search radius size in meters
 * @returns {FeatureCollection} a list of POIs with their type, id, etc. (cf: [opentripmap](https://dev.opentripmap.org/docs#))
 */
async function callRadius(lon: string, lat: string, radius = '1000') {
    const optionsDrink = {
        method: 'GET',
        url: 'https://api.opentripmap.com/0.1/en/places/radius',
        params: {
            radius: radius,
            lon: lon,
            lat: lat,
            apikey: key,
            kinds: 'bars,cafes,pubs,biergartens'
        },
        headers: {'Content-Type': 'application/json'}
    }

    try {
        const { data } = await axios.request(optionsDrink);
        return data
    } catch (error) {
        console.error(error);
    }
}

/**
 * make GET request to the OTM for city info.
 * @param {string} name Name of a city
 * @returns {Geoname} info of a search city their name, country, lat, lon, etc. (cf: [opentripmap](https://dev.opentripmap.org/docs#))
 */
async function callCity(name:string) {
    const optionsCity = {
        method: 'GET',
        url: 'https://api.opentripmap.com/0.1/en/places/geoname',
        params: {
            name: name,
            apikey: key
        },
        headers: {'Content-Type': 'application/json'}
    };
    
    try {
        const { data } = await axios.request(optionsCity);
        return data
    } catch (error) {
        console.error(error);
    }
}


/**
 * Handle GET request for city search route ('/otm/city').
 * @param {express.Request} req - HTTP Request object.
 * @param {express.Response} res - HTTP Response object.
 */
export async function getCity(req: express.Request, res: express.Response) {
    const cityName = req.query["name"]
    let radius = req.query["radius"]

    if(!cityName){
        res.status(400).send("Missing Argument name")
        return
    }
    if(!radius){
        radius = "1000"
    }
    const cityPose = await callCity(cityName as string)
    res.send( await callRadius(cityPose.lon,cityPose.lat, radius as string))
}

/**
 * Handle GET request for radius search route ('/otm/radius').
 * @param {express.Request} req - HTTP Request object.
 * @param {express.Response} res - HTTP Response object.
 */
export async function getRadius(req:express.Request, res: express.Response) {
    const lon = req.query["lon"] as string
    const lat = req.query["lat"] as string
    let radius = req.query["radius"]
    if(!lon || !lat){
        res.status(400).send("Missing Argument name")
        return
    }
    if(!radius){
        radius = "1000"
    }

    res.send( await callRadius(lon,lat,radius as string))
}

//TODO: fair une route ou l'on donne l'id un établicement pour avoir des détailles
//TODO: fair une route ou l'on donne 2 coordonée
